@@ -26,6 +26,7 @@
 #include "H5PropList.h"
 #include "H5Object.h"
 #include "H5PropList.h"
+#include "H5OcreatProp.h"
 #include "H5DxferProp.h"
 #include "H5DcreatProp.h"
 #include "H5FaccProp.h"
@@ -39,30 +40,34 @@
 #include "H5DataSet.h"
 #include "H5private.h"		// for HDfree
 
-#ifndef H5_NO_NAMESPACE
 namespace H5 {
 #ifndef H5_NO_STD
     using std::cerr;
     using std::endl;
 #endif  // H5_NO_STD
-#endif
 
 //--------------------------------------------------------------------------
 // Function:	DataSet default constructor
 ///\brief	Default constructor: creates a stub DataSet.
 // Programmer	Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
-DataSet::DataSet() : AbstractDs(), H5Object(), id(H5I_INVALID_HID) {}
+DataSet::DataSet() : H5Object(), AbstractDs(), id(H5I_INVALID_HID) {}
 
 //--------------------------------------------------------------------------
 // Function:	DataSet overloaded constructor
 ///\brief	Creates an DataSet object using the id of an existing dataset.
 ///\param	existing_id - IN: Id of an existing dataset
 // Programmer	Binh-Minh Ribler - 2000
+// Description
+//		incRefCount() is needed here to prevent the id from being closed
+//		prematurely.  That is, when application uses the id of an
+//		existing DataSet object to create another DataSet object.  So,
+//		when one of those objects is deleted, the id will be closed if
+//		the reference counter is only 1.
 //--------------------------------------------------------------------------
-DataSet::DataSet(const hid_t existing_id) : AbstractDs(), H5Object()
+DataSet::DataSet(const hid_t existing_id) : H5Object(), AbstractDs(), id(existing_id)
 {
-    id = existing_id;
+    incRefCount(); // increment number of references to this id
 }
 
 //--------------------------------------------------------------------------
@@ -71,9 +76,8 @@ DataSet::DataSet(const hid_t existing_id) : AbstractDs(), H5Object()
 ///\param	original - IN: DataSet instance to copy
 // Programmer	Binh-Minh Ribler - 2000
 //--------------------------------------------------------------------------
-DataSet::DataSet(const DataSet& original) : AbstractDs(original), H5Object(original)
+DataSet::DataSet(const DataSet& original) : H5Object(), AbstractDs(), id(original.id)
 {
-    id = original.getId();
     incRefCount(); // increment number of references to this id
 }
 
@@ -135,7 +139,8 @@ DataSpace DataSet::getSpace() const
       throw DataSetIException("DataSet::getSpace", "H5Dget_space failed");
    }
    //create dataspace object using the existing id then return the object
-   DataSpace data_space( dataspace_id );
+   DataSpace data_space;
+   f_DataSpace_setId(&data_space, dataspace_id);
    return( data_space );
 }
 
@@ -167,9 +172,11 @@ DSetCreatPropList DataSet::getCreatePlist() const
    {
       throw DataSetIException("DataSet::getCreatePlist", "H5Dget_create_plist failed");
    }
+
    // create and return the DSetCreatPropList object
-   DSetCreatPropList create_plist( create_plist_id );
-   return( create_plist );
+   DSetCreatPropList create_plist;
+   f_PropList_setId(&create_plist, create_plist_id);
+   return(create_plist);
 }
 
 //--------------------------------------------------------------------------
@@ -290,9 +297,13 @@ void DataSet::getSpaceStatus(H5D_space_status_t& status) const
 //--------------------------------------------------------------------------
 // Function:	DataSet::getVlenBufSize
 ///\brief	Returns the number of bytes required to store VL data.
+///\param	type - IN: Datatype, which is the datatype for the buffer
+///\param	space - IN: Selection for the memory buffer
 ///\return	Amount of storage
 ///\exception	H5::DataSetIException
 // Programmer	Binh-Minh Ribler - 2000
+// Modification
+//		Replaced the version without const parameter - Apr, 2014
 //--------------------------------------------------------------------------
 hsize_t DataSet::getVlenBufSize(const DataType& type, const DataSpace& space ) const
 {
@@ -312,17 +323,21 @@ hsize_t DataSet::getVlenBufSize(const DataType& type, const DataSpace& space ) c
 
 //--------------------------------------------------------------------------
 // Function:	DataSet::getVlenBufSize
-///\brief       This is an overloaded member function, kept for backward
-///		compatibility.  It differs from the above function in that it
-///             misses const's.  This wrapper will be removed in future release.
-///\return	Amount of storage
-///\exception	H5::DataSetIException
+// Purpose	This is an overloaded member function, kept for backward
+//		compatibility.  It differs from the above function in that it
+//		misses const's.  This wrapper will be removed in future release.
+// Return	Amount of storage
+// Exception	H5::DataSetIException
 // Programmer	Binh-Minh Ribler - 2000
+// Modification
+//		Modified to call its replacement. -BMR, 2014/04/16
+//		Removed from documentation. -BMR, 2016/03/07 1.8.17 and 1.10.0
+//		Removed from code. -BMR, 2016/08/11 1.8.18 and 1.10.1
 //--------------------------------------------------------------------------
-hsize_t DataSet::getVlenBufSize( DataType& type, DataSpace& space ) const
-{
-    return(getVlenBufSize((const DataType)type, (const DataSpace)space));
-}
+//hsize_t DataSet::getVlenBufSize( DataType& type, DataSpace& space ) const
+//{
+//    return(getVlenBufSize(type, space));
+//}
 
 //--------------------------------------------------------------------------
 // Function:	DataSet::vlenReclaim
@@ -591,7 +606,6 @@ void DataSet::extend( const hsize_t* size ) const
 ///\exception	H5::DataSetIException
 // Programmer	Binh-Minh Ribler - 2014
 // Modification
-//		Used the non-const version.
 //--------------------------------------------------------------------------
 void DataSet::fillMemBuf(const void *fill, const DataType& fill_type, void *buf, const DataType& buf_type, const DataSpace& space) const
 {
@@ -607,21 +621,25 @@ void DataSet::fillMemBuf(const void *fill, const DataType& fill_type, void *buf,
 
 //--------------------------------------------------------------------------
 // Function:	DataSet::fillMemBuf
-///\brief       This is an overloaded member function, kept for backward
-///		compatibility.  It differs from the above function in that it
-///             misses const's.  This wrapper will be removed in future release.
-///\param	fill - IN: Pointer to fill value to use - default NULL
-///\param	fill_type - IN: Datatype of the fill value
-///\param	buf - IN/OUT: Memory buffer to fill selection within
-///\param	buf_type - IN: Datatype of the elements in buffer
-///\param	space - IN: Dataspace describing memory buffer & containing selection to use
-///\exception	H5::DataSetIException
+// Purpose	This is an overloaded member function, kept for backward
+//		compatibility.  It differs from the above function in that it
+//		misses const's.  This wrapper will be removed in future release.
+// Param 	fill - IN: Pointer to fill value to use - default NULL
+// Param 	fill_type - IN: Datatype of the fill value
+// Param 	buf - IN/OUT: Memory buffer to fill selection within
+// Param 	buf_type - IN: Datatype of the elements in buffer
+// Param 	space - IN: Dataspace describing memory buffer & containing selection to use
+// Exception	H5::DataSetIException
 // Programmer	Binh-Minh Ribler - 2000
+// Modification
+//		Modified to call its replacement. -BMR, 2014/04/16
+//		Removed from documentation. -BMR, 2016/03/07 1.8.17 and 1.10.0
+//		Removed from code. -BMR, 2016/08/11 1.8.18 and 1.10.1
 //--------------------------------------------------------------------------
-void DataSet::fillMemBuf(const void *fill, DataType& fill_type, void *buf, DataType& buf_type, DataSpace& space)
-{
-    fillMemBuf(fill, (const DataType)fill_type, buf, (const DataType)buf_type, (const DataSpace)space);
-}
+//void DataSet::fillMemBuf(const void *fill, DataType& fill_type, void *buf, DataType& buf_type, DataSpace& space)
+//{
+//    fillMemBuf(fill, (const DataType)fill_type, buf, (const DataType)buf_type, (const DataSpace)space);
+//}
 
 //--------------------------------------------------------------------------
 // Function:	DataSet::fillMemBuf
@@ -631,6 +649,8 @@ void DataSet::fillMemBuf(const void *fill, DataType& fill_type, void *buf, DataT
 ///\param	space - IN: Dataspace describing memory buffer & containing selection to use
 ///\exception	H5::DataSetIException
 // Programmer	Binh-Minh Ribler - 2000
+// Modification
+//		Replaced the version without const parameter - Apr, 2014
 //--------------------------------------------------------------------------
 void DataSet::fillMemBuf(void *buf, const DataType& buf_type, const DataSpace& space) const
 {
@@ -645,19 +665,23 @@ void DataSet::fillMemBuf(void *buf, const DataType& buf_type, const DataSpace& s
 
 //--------------------------------------------------------------------------
 // Function:    DataSet::fillMemBuf
-///\brief       This is an overloaded member function, kept for backward
-///		compatibility.  It differs from the above function in that it
-///             misses const's.  This wrapper will be removed in future release.
-///\param       buf - IN/OUT: Memory buffer to fill selection within
-///\param       buf_type - IN: Datatype of the elements in buffer
-///\param       space - IN: Dataspace describing memory buffer & containing selection to use
-///\exception   H5::DataSetIException
+// Purpose	This is an overloaded member function, kept for backward
+//		compatibility.  It differs from the above function in that it
+//		misses const's.  This wrapper will be removed in future release.
+// Param        buf - IN/OUT: Memory buffer to fill selection within
+// Param        buf_type - IN: Datatype of the elements in buffer
+// Param        space - IN: Dataspace describing memory buffer & containing selection to use
+// Exception	H5::DataSetIException
 // Programmer   Binh-Minh Ribler - 2000
+// Modification
+//		Modified to call its replacement. -BMR, 2014/04/16
+//		Removed from documentation. -BMR, 2016/03/07 1.8.17 and 1.10.0
+//		Removed from code. -BMR, 2016/08/11 1.8.18 and 1.10.1
 //--------------------------------------------------------------------------
-void DataSet::fillMemBuf(void *buf, DataType& buf_type, DataSpace& space)
-{
-    fillMemBuf(buf, (const DataType)buf_type, (const DataSpace)space);
-}
+//void DataSet::fillMemBuf(void *buf, DataType& buf_type, DataSpace& space)
+//{
+//    fillMemBuf(buf, (const DataType)buf_type, (const DataSpace)space);
+//}
 
 //--------------------------------------------------------------------------
 // Function:    DataSet::getId
@@ -761,12 +785,28 @@ void DataSet::p_setId(const hid_t new_id)
     try {
         close();
     }
-    catch (Exception close_error) {
+    catch (Exception& close_error) {
         throw DataSetIException(inMemFunc("p_setId"), close_error.getDetailMsg());
     }
    // reset object's id to the given id
    id = new_id;
 }
+
+//--------------------------------------------------------------------------
+// Function:    f_PropList_setId - friend
+// Purpose:     This function is friend to class H5::PropList so that it
+//              can set PropList::id in order to work around a problem
+//              described in the JIRA issue HDFFV-7947.
+//              Applications shouldn't need to use it.
+// param        dset   - IN/OUT: DataSet object to be changed
+// param        new_id - IN: New id to set
+// Programmer   Binh-Minh Ribler - 2015
+//--------------------------------------------------------------------------
+void f_PropList_setId(PropList* plist, hid_t new_id)
+{
+    plist->p_setId(new_id);
+}
+
 #endif // DOXYGEN_SHOULD_SKIP_THIS
 
 //--------------------------------------------------------------------------
@@ -805,11 +845,8 @@ DataSet::~DataSet()
     try {
 	close();
     }
-    catch (Exception close_error) {
+    catch (Exception& close_error) {
 	cerr << "DataSet::~DataSet - " << close_error.getDetailMsg() << endl;
     }
 }
-
-#ifndef H5_NO_NAMESPACE
 } // end namespace
-#endif
